Description Usage Arguments Value Author(s) See Also Examples
The function pairDistPlot extracts and plots pairwise distances
between different groups (graphs use ggplot2). The function
pairDistPlot does the same, without the graphs.
pairDistPlot is a generic function with methods for the
following types of objects:
- dist
- matrix (only numeric data)
- genind objects (genetic markers, individuals)
- DNAbin objects (DNA sequences)
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | pairDist(x, ...)
pairDistPlot(x, ...)
## S3 method for class 'dist'
pairDistPlot(x, grp, within=FALSE, sep="-", data=TRUE,
violin=TRUE, boxplot=TRUE, jitter=TRUE, ...)
## S3 method for class 'matrix'
pairDistPlot(x, grp, within=FALSE, sep="-", data=TRUE,
violin=TRUE, boxplot=TRUE, jitter=TRUE, ...)
## S3 method for class 'genind'
pairDistPlot(x, grp, within=FALSE, sep="-", data=TRUE,
violin=TRUE, boxplot=TRUE, jitter=TRUE, ...)
## S3 method for class 'DNAbin'
pairDistPlot(x, grp, within=FALSE, sep="-", data=TRUE,
violin=TRUE, boxplot=TRUE, jitter=TRUE, ...)
|
x |
pairwise distances provided as a |
grp |
a factor defining a grouping of individuals. |
within |
a logical indicating whether to keep within-group comparisons. |
sep |
a character used as separator between group names |
data |
a logical indicating whether data of the plot should be returned. |
violin |
a logical indicating whether a violinplot should be generated. |
boxplot |
a logical indicating whether a boxplot should be generated. |
jitter |
a logical indicating whether a jitter-plot should be generated. |
... |
further arguments to be used by other functions; used for
|
A list with different components, depending on the values of the
arguments. Plots are returned as ggplot2 objects.
Thibaut Jombart t.jombart@imperial.ac.uk.
gengraph to identify connectivity based on distances.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.